@@ -20,12 +20,16 @@ class JitsiConfig(Config):
 
     def read_config(self, config, **kwargs):
         self.jitsi_url = config.get("jitsi_url")
+        self.jitsi_app_id = config.get("jitsi_app_id")
+        self.jitsi_app_secret = config.get("jitsi_app_secret")
 
     def generate_config_section(self, **kwargs):
         return """\
         ## Jitsi ##
 
-        # The url for jitsi server
+        # The url, id and secret for jitsi video conferencing
         #
         #jitsi_url: "https://jitsi.example.com"
+        #jitsi_app_id: "example_app_id"
+        #jitsi_app_secret: "example_app_secret"
         """
