@@ -20,12 +20,14 @@ class NoticeConfig(Config):
 
     def read_config(self, config, **kwargs):
         self.notice_url = config.get("notice_url")
+        self.notice_key = config.get("notice_key")
 
     def generate_config_section(self, **kwargs):
         return """\
         ## Notice ##
 
-        # The url for notice server
+        # The url and key for notice server
         #
         #notice_url: "https://notice.example.com"
+        #notice_key: "example_key"
         """
